==> nextcloud-23.0.9.tgz: nextcloud/apps/text/l10n/zh_CN.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "新建文本文件",
    "The file was uploaded" : "文件已上传",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上传文件超出了php.ini中upload_max_filesize的限制",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传文件超出了HTML表单中MAX_FILE_SIZE的限制",
    "The file was only partially uploaded" : "仅部分文件成功上传",
    "No file was uploaded" : "未有上传的文件",
    "Missing a temporary folder" : "缺失一个临时文件夹",
    "Could not write file to disk" : "无法向磁盘中写入文件",
    "A PHP extension stopped the file upload" : "一个PHP扩展插件终止了文件上传",
    "No file uploaded or file size exceeds maximum of %s" : "没有文件上传成功或者文件大小超出了最大%s的限制",
    "Nextcloud Text" : "Nextcloud 文本",
    "text document" : "文本文档",
    "Readme" : "自述文件",
    "Text" : "文本 ",
    "📝 Collaborative document editing" : "文档协作编辑",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 协作式的文档编辑！**\n\n- **📝 专注的写作：** 无干扰，只有您需要的格式化。\n- **🙋 一起工作：** 与朋友和同事共享协作，无论他们是否使用Nextcloud！\n- **💾 开放标准：** 文件将保存为 [Markdown](https://en.wikipedia.org/wiki/Markdown)，所以您也可以使用任何其他文本应用。\n- **✊ 雄厚基础：** 我们使用 [🐈 tiptap](https://tiptap.scrumpy.io) ，它基于 [🦉 ProseMirror](https://prosemirror.net) – 非常感谢它们！",
    "Use current version" : "使用当前版本",
    "Use the saved version" : "使用保存的版本",
    "Document idle for {timeout} minutes, click to continue editing" : "文档已闲置 {timeout} 分钟，点击以继续编辑",
    "Reconnect" : "重新连接",
    "The document has been changed outside of the editor. The changes cannot be applied." : "本文档在编辑器外被更改。无法应用更改。",
    "File could not be loaded. Please check your internet connection." : "无法加载文件。 请检查您的互联网连接。",
    "Edit guest name" : "编辑访客姓名",
    "Guest" : "访客",
    "Save guest name" : "保存访客姓名",
    "guest" : "访客",
    "Show author colors" : "显示作者颜色",
    "Author colors are only shown until everyone has closed the document." : "直到所有人都关闭了文档，才会显示作者颜色。",
    "Saving …" : "保存中 …",
    "Saved" : "已保存",
    "Last saved {lastSaved}" : "最近保存 {lastSave}",
    "Unsaved changes" : "未保存的更改",
    "Formatting help" : "排版帮助",
    "Speed up your writing with simple shortcuts." : "利用简单快捷键加速写作",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "只需输入 markdown 语法或从下面使用键盘快捷键。",
    "Just type the Markdown syntax from below." : "只需从下面输入 markdown 语法",
    "Style" : "样式",
    "Syntax" : "语法",
    "Keyboard shortcuts" : "键盘快捷键",
    "Bold" : "加粗",
    "Bold text" : "粗文本",
    "Ctrl" : "Ctrl",
    "Italic" : "斜体",
    "Italicized text" : "斜文本",
    "Strikethrough" : "删除线",
    "Mistaken text" : "错误文本",
    "Shift" : "Shift",
    "Heading 1" : "标题 1",
    "Heading level 1" : "标题级 1",
    "Heading 6" : "标题 6",
    "Heading level 6" : "标题级 6",
    "Unordered list" : "无编号列表",
    "An item" : "一个项目",
    "Ordered list" : "编号列表",
    "First item" : "第一个项目",
    "Checklist" : "清单",
    "Blockquote" : "块引用",
    "Quoted text" : "引用文本",
    "Code block" : "代码块",
    "Some code" : "一些代码",
    "Upload from computer" : "从电脑上传",
    "Insert from Files" : "从文件插入",
    "Update Link" : "更新链接",
    "Add Link" : "添加链接",
    "Link file" : "链接文件",
    "Remove Link" : "移除链接",
    "Select file to link to" : "选择文件链接至",
    "Unsupported image type" : "不支持图片格式",
    "Show rich workspaces" : "显示富文本编辑区",
    "Add notes, lists or links …" : "添加笔记、列表或链接...",
    "Undo" : "撤销",
    "Redo" : "重做",
    "Headings" : "标题",
    "Heading 2" : "标题 2",
    "Heading 3" : "标题 3",
    "Heading 4" : "标题 4",
    "Heading 5" : "标题 5",
    "Info" : "信息",
    "Success" : "成功",
    "Warning" : "警告",
    "Table" : "表格",
    "Insert emoji" : "插入 emoji",
    "Insert attachment" : "插入附件",
    "Command" : "命令",
    "Control" : "控制",
    "Edit" : "编辑",
    "New text document" : "新建文本文档",
    "Enter your name so other users can see who is editing" : "输入您的姓名以便他人看到谁在编辑",
    "Insert image" : "插入图片",
    "Insert an image" : "插入一张图片",
    "Currently active users:" : "当前活跃用户：",
    "_and %n other editor_::_and %n other editors_" : ["和 %n 位其他编辑者"],
    "ToDo list" : "待办事项清单",
    "Emoji picker" : "Emoji 选择器",
    "Todo item" : "待办事项",
    "Alt" : "Alt"
},
"nplurals=1; plural=0;");

==> nextcloud-24.0.9.tgz: nextcloud/apps/text/l10n/zh_CN.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "新建文本文件",
    "The file was uploaded" : "文件已上传",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上传文件超出了php.ini中upload_max_filesize的限制",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传文件超出了HTML表单中MAX_FILE_SIZE的限制",
    "The file was only partially uploaded" : "仅部分文件成功上传",
    "No file was uploaded" : "未有上传的文件",
    "Missing a temporary folder" : "缺失一个临时文件夹",
    "Could not write file to disk" : "无法向磁盘中写入文件",
    "A PHP extension stopped the file upload" : "一个PHP扩展插件终止了文件上传",
    "No file uploaded or file size exceeds maximum of %s" : "没有文件上传成功或者文件大小超出了最大%s的限制",
    "Nextcloud Text" : "Nextcloud 文本",
    "text document" : "文本文档",
    "Readme" : "自述文件",
    "Text" : "文本 ",
    "📝 Collaborative document editing" : "文档协作编辑",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 协作式的文档编辑！**\n\n- **📝 专注的写作：** 无干扰，只有您需要的格式化。\n- **🙋 一起工作：** 与朋友和同事共享协作，无论他们是否使用Nextcloud！\n- **💾 开放标准：** 文件将保存为 [Markdown](https://en.wikipedia.org/wiki/Markdown)，所以您也可以使用任何其他文本应用。\n- **✊ 雄厚基础：** 我们使用 [🐈 tiptap](https://tiptap.scrumpy.io) ，它基于 [🦉 ProseMirror](https://prosemirror.net) – 非常感谢它们！",
    "Use current version" : "使用当前版本",
    "Use the saved version" : "使用保存的版本",
    "Document idle for {timeout} minutes, click to continue editing" : "文档已闲置 {timeout} 分钟，点击以继续编辑",
    "Reconnect" : "重新连接",
    "The document has been changed outside of the editor. The changes cannot be applied." : "本文档在编辑器外被更改。无法应用更改。",
    "File could not be loaded. Please check your internet connection." : "无法加载文件。 请检查您的互联网连接。",
    "Edit guest name" : "编辑访客姓名",
    "Guest" : "访客",
    "Save guest name" : "保存访客姓名",
    "guest" : "访客",
    "Show author colors" : "显示作者颜色",
    "Author colors are only shown until everyone has closed the document." : "直到所有人都关闭了文档，才会显示作者颜色。",
    "Saving …" : "保存中 …",
    "Saved" : "已保存",
    "Last saved {lastSaved}" : "最近保存 {lastSave}",
    "Unsaved changes" : "未保存的更改",
    "Formatting help" : "排版帮助",
    "Speed up your writing with simple shortcuts." : "利用简单快捷键加速写作",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "只需输入 markdown 语法或从下面使用键盘快捷键。",
    "Just type the Markdown syntax from below." : "只需从下面输入 markdown 语法",
    "Style" : "样式",
    "Syntax" : "语法",
    "Keyboard shortcuts" : "键盘快捷键",
    "Shift" : "Shift",
    "Bold" : "加粗",
    "Bold text" : "粗文本",
    "Ctrl" : "Ctrl",
    "Italic" : "斜体",
    "Italicized text" : "斜文本",
    "Strikethrough" : "删除线",
    "Mistaken text" : "错误文本",
    "Underline" : "下划线",
    "Heading 1" : "标题 1",
    "Heading level 1" : "标题级 1",
    "Heading 6" : "标题 6",
    "Heading level 6" : "标题级 6",
    "Unordered list" : "无编号列表",
    "An item" : "一个项目",
    "Ordered list" : "编号列表",
    "First item" : "第一个项目",
    "Checklist" : "清单",
    "Blockquote" : "块引用",
    "Quoted text" : "引用文本",
    "Code block" : "代码块",
    "Some code" : "一些代码",
    "Upload from computer" : "从电脑上传",
    "Insert from Files" : "从文件插入",
    "Remove link" : "删除链接",
    "Update link" : "更新链接",
    "_%n word_::_%n words_" : ["%n 字"],
    "_%n char_::_%n chars_" : ["%n 字符"],
    "Unsupported image type" : "不支持图片格式",
    "Show rich workspaces" : "显示富文本编辑区",
    "Add notes, lists or links …" : "添加笔记、列表或链接...",
    "Undo" : "撤销",
    "Redo" : "重做",
    "Headings" : "标题",
    "Heading 2" : "标题 2",
    "Heading 3" : "标题 3",
    "Heading 4" : "标题 4",
    "Heading 5" : "标题 5",
    "Info" : "信息",
    "Success" : "成功",
    "Warning" : "警告",
    "Table" : "表格",
    "Insert emoji" : "插入 emoji",
    "Insert attachment" : "插入附件",
    "Command" : "命令",
    "Control" : "控制",
    "Edit" : "编辑",
    "Enter your name so other users can see who is editing" : "输入您的姓名以便他人看到谁在编辑",
    "Todo item" : "待办事项",
    "Insert an image" : "插入一张图片",
    "Alt" : "Alt",
    "Update Link" : "更新链接",
    "Add Link" : "添加链接",
    "Link file" : "链接文件",
    "Remove Link" : "移除链接",
    "Select file to link to" : "选择文件链接至",
    "ToDo list" : "待办事项清单",
    "Emoji picker" : "Emoji 选择器",
    "Insert image" : "插入图片"
},
"nplurals=1; plural=0;");
